# -*- coding: utf-8 -*-

"""

  exceptions
  ~~~~~~~~~~

  contains exceptions exported by :py:mod:`canteen`.

  :author: Sam Gammon <sg@samgammon.com>
  :copyright: (c) Sam Gammon, 2014
  :license: This software makes use of the MIT Open Source License.
            A copy of this license is included as ``LICENSE.md`` in
            the root of the project.

"""


class Error(Exception):
    """ Top-level error for all of :py:mod:`canteen`. """
